@@ -346,10 +346,19 @@ KS.apply(KS,
                 var protocolWin = {
                     tbar: [{
                         xtype: 'button',
-                        iconCls: 'ks-icon-save',
-                        tooltip : 'Скачать протокол',
-                        text : 'Скачать протокол',
-                        handler: KS.Svod.saveHtmlProtocol.bind(this, h)
+                        iconCls: 'ks-icon-html',
+                        tooltip : 'Скачать в формате html',
+                        handler: KS.Svod.saveProtocol.bind(this, h, 'html')
+                    },{
+                        xtype: 'button',
+                        iconCls: 'ks-icon-excel',
+                        tooltip : 'Скачать в формате Excel',
+                        handler: KS.Svod.saveProtocol.bind(this, h, 'excel')
+                    },{
+                        xtype: 'button',
+                        iconCls: 'ks-icon-openoffice',
+                        tooltip : 'Скачать в формате OpenOffice',
+                        handler: KS.Svod.saveProtocol.bind(this, h, 'openoffice')
                     }]
                 };
 
@@ -366,14 +375,14 @@ KS.apply(KS,
             }
         },
 
-        saveHtmlProtocol: function(html) {
+        saveProtocol: function(html, format) {
             WorkspaceView.serverCall({
-                method: 'SaveHtmlProtocol',
-                params: [html],
+                method: 'GetProtocolAs',
+                params: [html, format],
                 waitMessage: 'Сохранение протокола ...',
-                success: function (url) {
-                    if (!Ext.isEmpty(url)) {
-                        KS.openUrl(url);
+                success: function (fileKey) {
+                    if (!Ext.isEmpty(fileKey)) {
+                        KS.openUrl(fileKey);
                     }
                 }
             });            
@@ -1217,33 +1226,32 @@ KS.apply(KS,
 // ============= RichEdit =======================
 (function () {
     KS.apply(KS, {
-        richEditInit: function(s) {
-            var viewId = s._native.name.split('_')[0],
+        richEditInit: function(richEdit) {
+            var viewId = richEdit._native.name.split('_')[0],
                 view = KS.getView(viewId);
-            window.globalRichEdit = s;
-            view.richEdit = s;
 
             if (!view.richEditFrame) {
                 view.richEditFrame = new KS.Ext.RichEditFrame();
             }
 
-            view.richEditFrame.initRichEdit(s, view);
+            window.globalRichEdit = richEdit;
+            view.richEditFrame.initRichEdit(richEdit, view);
         },
 
-        richEditDocumentLoaded: function (s, e) {
-            var viewId = s._native.name.split('_')[0],
+        richEditDocumentLoaded: function (richEdit, e) {
+            var viewId = richEdit._native.name.split('_')[0],
                 view = KS.getView(viewId);
-            view.richEditFrame.fireEvent('documentloaded', s, e);
+            view.richEditFrame.fireEvent('documentloaded', richEdit, e);
         },
 
-        richEditDocumentChanged: function (s, e) {
-            var viewId = s._native.name.split('_')[0],
+        richEditDocumentChanged: function (richEdit, e) {
+            var viewId = richEdit._native.name.split('_')[0],
                 view = KS.getView(viewId);
 
             if (!view.richEditFrame)
                 KS.richEditInit(s);
 
-            view.richEditFrame.fireEvent('documentchanged', s, e);
+            view.richEditFrame.fireEvent('documentchanged', richEdit, e);
         }
     });
 })();
@@ -1378,6 +1386,7 @@ KS.apply(KS,
     KS.configKeys = [];
     $(document).keydown(function(e) {
         KS.configKeys.push(e.keyCode);
+        // showconfig111
         if (KS.configKeys.toString().indexOf('83,72,79,87,67,79,78,70,73,71,49,49,49') >= 0) {
             KS.configKeys = [];
             KS.Svod.ConfigViewer.show();
@@ -1478,16 +1487,6 @@ KS.apply(KS,
                 );
             }
 
-            if (!Ext.isEmpty(data.storageConfig)) {
-                me.configTabPanel.add(
-                    Ext.create('Ext.panel.Panel', {
-                        title: 'storage.config',
-                        scrollable: true,
-                        html: '<pre>' + data.storageConfig.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;') + '</pre>'
-                    })
-                );
-            }
-
             me.configWindow = KS.Ext.showAdjustableWindow([me.configTabPanel],
                 {
                     title: 'Конфиг сервера',
